/*
 *  profilesx
 *  Copyright (C) 2010 Nicolai Hess
 *  
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *  
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef PROFILESX_PROFILE_WAITDIALOG_H
#define PROFILESX_PROFILE_WAITDIALOG_H

#include <glib.h>
#include <gtk/gtk.h>
#include "profilesx-control-panel-plugin.h"

typedef struct _pdata pdata;

void show_progress_bar(const gchar* profile_name, 
		       user_data_t* data, 
		       gboolean for_new,
		       GtkWidget* widget);
#endif
